﻿(function () {

    "use strict";

    angular.module("EnrApp")
           .controller("MainController", ["$scope", "$window", "$filter", "jsonDataFetcher", "secondsCountdown", "enrModeManager",
                       function ($scope, $window, $filter, jsonDataFetcher, secondsCountdown, enrModeManager) {

               // Start by pulling settings data (which will also give us version information)
               jsonDataFetcher.fetchSingleJson("settings", false, false, function (settingsJson) {
                   jsonDataFetcher.registerVersion(settingsJson.VersionType);

                   // Now that we know what our version is, pull the rest of the data we need on startup.
                   jsonDataFetcher.fetchMultipleJson(["statewideElectionsC", "statewideTickerC", "additionalSettings"], [true, true, false], [false, false, true], function (jsonResults) {
                       var officeListJson = jsonResults[0];
                       var tickerJson = jsonResults[1];
                       var additionalSettings = jsonResults[2];

                       $scope.ElectionDate = new Date(settingsJson.CurrentElection);
                       $scope.VersionTimestamp = settingsJson.VersionCode;

                       $scope.DefaultMap = settingsJson.DefaultMapName;

                       settingsJson.PolParties.AdditionalColors = additionalSettings.AdditionalColors;
                       $scope.MapColorsData = settingsJson.PolParties;
                       $scope.MapGeoData = undefined;

                       $scope.ReportingMeterValue = officeListJson.JurisdictionsReporting.TOTAL_ALLPRECINCTSREPORTING / officeListJson.JurisdictionsReporting.TOTAL_ALLPRECINCTS;
                       $scope.PercentReporting = $filter("percentage")($scope.ReportingMeterValue, 1);
                       $scope.TotalPrecincts = officeListJson.JurisdictionsReporting.TOTAL_ALLPRECINCTS;

                       var initialSecondsTillRefresh = settingsJson.IntervalInMinutes * 60;
                       secondsCountdown.start(initialSecondsTillRefresh, function () { $window.location.reload(); });
                       $scope.SecondsTilRefresh = secondsCountdown.secondsRemaining;
                       $scope.RefreshMeterValue = function () { return 1 - ($scope.SecondsTilRefresh() / initialSecondsTillRefresh); };

                       $scope.OfficeListData = officeListJson;
                       $scope.showOfficeList = true;
                       $scope.$on(enrModeManager.modeChangeEventName, function (event, newMode) {
                           $scope.showOfficeList = newMode === enrModeManager.modeEnum.offices;
                       });

                       $scope.TickerData = tickerJson.ElectionSummaries.Race;
                       // Sometimes single entries aren't stored as arrays; for code simplicity force it to be an array. (This could be some kind of reusable service)
                       angular.forEach($scope.TickerData, function(tickerOffice) {
                           if (!angular.isArray(tickerOffice.Candidates.Candidate))
                               tickerOffice.Candidates.Candidate = [tickerOffice.Candidates.Candidate];
                       });
                   });
               });
           }]);

}());
